var recording = true;  // the flag determine to record or not

function appendTo(editor, text) {
	var doc = editor.getDoc();
	var cursor = doc.getCursor(); // gets the line number in the cursor position
	var line = doc.getLine(cursor.line); // get the line contents
	var pos = { // create a new object to avoid mutation of the original selection
	    line: cursor.line,
	    ch: line.length - 1 // set the character position to the end of the line
	}
	doc.replaceRange(text + "\n", pos); // adds a new line
}

function textTruncate(str, length, ending) {
  if (length == null) {
    length = 100;
  }
  if (ending == null) {
    ending = '...';
  }
  if (str.length > length) {
    return str.substring(0, length - ending.length) + ending;
  } else {
    return str;
  }
};

function escape_string(string) {
  return ('' + string).replace(/["'\\\n\r\u2028\u2029]/g, function (character) {
    // Escape all characters not included in SingleStringCharacters and
    // DoubleStringCharacters on
    // http://www.ecma-international.org/ecma-262/5.1/#sec-7.8.4
    switch (character) {
      case '"':
      case "'":
      case '\\':
        return '\\' + character
      // Four possible LineTerminator characters need to be escaped:
      case '\n':
        return '\\n'
      case '\r':
        return '\\r'
      case '\u2028':
        return '\\u2028'
      case '\u2029':
        return '\\u2029'
    }
  })
};

	
/* 
 * elem attributes
 * lang
 */
function determineLocator(elem, lang) {
  if (elem.id) {
		
    switch (lang) {
    case "ruby":        
			return 'find_element(:id, "' + elem.id + '")'       
		case "python":
			return 'find_element_by_id("' + elem.id +  '")';
    case "javascript":
      return 'findElement(By.id("' + elem.id +  '"))';
    case "java":
      return 'findElement(By.id("' + elem.id +  '"))';
    case "csharp":
      return 'FindElement(By.Id("' + elem.id +  '"))';
		case "watir":
			return '(:id => "' + elem.id +'")'  		
		}

  } else if (elem.name) {

    switch (lang) {
    case "ruby":        
      return 'find_element(:name, "' + elem.name + '")'       
		case "python":
      return 'find_element_by_name("' + elem.name + '")'       
    case "javascript":
      return 'findElement(By.name("' + elem.name +  '"))';
    case "java":
      return 'findElement(By.name("' + elem.name +  '"))';
    case "csharp":
      return 'FindElement(By.Name("' + elem.name +  '"))';
		case "watir":
			return '(:name => "' + elem.name +'")'  		
		}

  } else if (elem.xpath) {

    switch (lang) {
    case "ruby":        
      return 'find_element(:xpath, "' + elem.xpath + '")'       
		case "python":
      return 'find_element_by_xpath("' + elem.xpath + '")'       
    case "javascript":
      return 'findElement(By.xpath("' + elem.xpath +  '"))';
    case "java":
      return 'findElement(By.xpath("' + elem.xpath +  '"))';
    case "csharp":
      return 'FindElement(By.Xpath("' + elem.xpath +  '"))';
		case "watir":
			return '(:xpath => "' + elem.xpath +'")'  		
		}
		
  }
  return ""
}

function resize_window() {
	if ($("#footer").is(":visible")) {
		height_diff = 77 + 48 - 8;			
	} else { 
		height_diff = 77 - 8;			
	}
	win_height = window.innerHeight;
	// console.log("resize window => " + win_height + " - " +  height_diff);
	ruby_editor.setSize(null, win_height - height_diff);
  python_editor.setSize(null, win_height - height_diff);
  javascript_editor.setSize(null, win_height - height_diff);
  java_editor.setSize(null, win_height - height_diff);
  csharp_editor.setSize(null, win_height - height_diff);
  watir_editor.setSize(null, win_height -height_diff);
}

$(document).ready(function(){

	$( "#start-recording-btn" ).bind( "click", function() {
		$("#start-recording-btn").hide();
		$("#stop-recording-btn").show();
		recording = true;
	});	
	
	$( "#stop-recording-btn" ).bind( "click", function() {
		$("#start-recording-btn").show();
		$("#stop-recording-btn").hide();
		recording = false
	});	

  ruby_editor = CodeMirror.fromTextArea(document.getElementById("scripts-webdriver-ruby"), {
     lineNumbers: true,
     lineWrapping: true,
     mode: "ruby",
     foldGutter: true,
     gutters: ["CodeMirror-linenumbers"]
  });

  python_editor = CodeMirror.fromTextArea(document.getElementById("scripts-webdriver-python"), {
     lineNumbers: true,
     lineWrapping: true,
     mode: "python",
     foldGutter: true,
     gutters: ["CodeMirror-linenumbers"]
  });
  
  javascript_editor = CodeMirror.fromTextArea(document.getElementById("scripts-webdriver-javascript"), {
     lineNumbers: true,
     lineWrapping: true,
     mode: "javascript",
     foldGutter: true,
     gutters: ["CodeMirror-linenumbers"]
  });

  java_editor = CodeMirror.fromTextArea(document.getElementById("scripts-webdriver-java"), {
     lineNumbers: true,
     lineWrapping: true,
     mode: "javascript",
     foldGutter: true,
     gutters: ["CodeMirror-linenumbers"]
  });

  csharp_editor = CodeMirror.fromTextArea(document.getElementById("scripts-webdriver-csharp"), {
     lineNumbers: true,
     lineWrapping: true,
     mode: "javascript",
     gutters: ["CodeMirror-linenumbers"]
  });
  
  watir_editor = CodeMirror.fromTextArea(document.getElementById("scripts-watir"), {
     lineNumbers: true,
     lineWrapping: true,
     mode: "ruby",
     foldGutter: true,
     gutters: ["CodeMirror-linenumbers"]
  });
		
	
	$( "#clear-btn" ).bind( "click", function() {
		// TODO only clear the active one
		ruby_editor.setValue("");
		python_editor.setValue("");
		watir_editor.setValue("");
		javascript_editor.setValue("");
		java_editor.setValue("");
		csharp_editor.setValue("");
	});	
	
	$( "#copy-to-clipboard-btn" ).bind( "click", function() {
	  var active_tab_id = $("div.active").attr("id");
		var brRegex = /<br\s*[\/]?>/gi;
	  var $temp = $("<textarea>");
	  $("body").append($temp);
		var scripts;
		if (active_tab_id == "ruby") {		
			scripts = ruby_editor.getValue().replace("\n", "\r\n").replace(brRegex, "\r\n");
		} else if (active_tab_id == "python") {
			scripts = python_editor.getValue().replace("\n", "\r\n").replace(brRegex, "\r\n");
    } else if (active_tab_id == "watir") {
      scripts = watir_editor.getValue().replace("\n", "\r\n").replace(brRegex, "\r\n");
    } else if (active_tab_id == "javascript") {
      scripts = javascript_editor.getValue().replace("\n", "\r\n").replace(brRegex, "\r\n");
    } else if (active_tab_id == "java") {
      scripts = java_editor.getValue().replace("\n", "\r\n").replace(brRegex, "\r\n");
    } else if (active_tab_id == "csharp") {
      scripts = csharp_editor.getValue().replace("\n", "\r\n").replace(brRegex, "\r\n");
		} else {
			
		}
		$temp.val(scripts).select();		
	  document.execCommand("copy");
	  $temp.remove();
	});	
	
	
	$("#close-footer").bind("click", function() {
		console.log("close footer....");
		$("#footer").remove();
		resize_window();
	});
	
	resize_window();
	$( window ).resize(function() {
		resize_window();
	});
	
  $('.tabs').tabs( {
  	onShow: function() {	
			ruby_editor.refresh();
			python_editor.refresh();
			watir_editor.refresh();
			javascript_editor.refresh();
			java_editor.refresh();
			csharp_editor.refresh();
  	}
  });
	
	
  var carouselElement = document.getElementById('test-automation-advice');
  var carouselInstance = M.Carousel.init(carouselElement, {
      fullWidth: true,
      indicators: false  	
  });
  // carouselInstance.set(5); // Set to nth slide. But it show animations
		
  setInterval(function() {
    $('.carousel').carousel('next');
  }, 10000); // every 10 seconds
	
  chrome.extension.sendMessage({command: "getURL"}, 
     function(response) {
        tabURL = response.navURL;
				// console.log(tabURL)
				
		$("#site_url").html(textTruncate(tabURL, 42));
		
		appendTo(ruby_editor, "driver = Selenium::WebDriver.for :chrome")
		appendTo(ruby_editor, 'driver.get("' +  tabURL + '")');

        appendTo(python_editor, "driver = webdriver.Chrome()")
        appendTo(python_editor, 'driver.get("' +  tabURL + '")');
                
        appendTo(javascript_editor, "var webdriver = require('selenium-webdriver'), By = webdriver.By;")
        appendTo(javascript_editor, "var driver = new webdriver.Builder().forBrowser('chrome').build();")
        appendTo(javascript_editor, 'driver.get("' +  tabURL + '")');
                
        appendTo(java_editor, "static WebDriver driver = new ChromeDriver();")
        appendTo(java_editor, 'driver.get("' +  tabURL + '");');

        appendTo(csharp_editor, "static WebDriver driver = new ChromeDriver();")
        appendTo(csharp_editor, 'driver.Get("' +  tabURL + '");');
        
		appendTo(watir_editor, "browser = Watir::Browser.new :chrome")
		appendTo(watir_editor, 'browser.goto "' +  tabURL +  '"');
        
	});
		
	chrome.runtime.onMessage.addListener(
	  function(request, sender, sendResponse) {
      var elem = {};
      elem["id"] = request.elem_id;
      elem["name"] = request.elem_name;
      elem["xpath"] = request.elem_xpath;

			if (request.command == "getURL") { 
				// console.log("[getURL] activeTab" + activeTab.url);
      	sendResponse( {navURL: activeTab.url} );
				return;
			}
			
			if (!recording) {
				// not recording 
				return;
			}
      
      switch (request.command) {
				
      case "verifyText": 
				// console.log("[verifyText]" + request.text);
				the_text = escape_string(request.text);
				appendTo(ruby_editor, 'expect(driver.find_element(:tag_name, "body").text).to include("' + the_text + '")');				
				appendTo(python_editor, 'assertIn("' +  the_text + '", driver.find_element_by_tag_name("body").text)');				
				appendTo(javascript_editor, 'driver.findElement(By.tagName("body")).getText().then(function(the_page_text) { \n  assert((the_page_text.includes("' +  request_title +'")); \n});'); 				
				appendTo(java_editor, 'asset driver.findElement(By.tagName("body")).getText().contains("' + the_text + '")'); 
				appendTo(csharp_editor, 'Assert.IsTrue(driver.FindElement(By.TagName("body")).Text.Contains("' + the_text + '")'); 
				appendTo(watir_editor, 'expect(browser.text).to include("' + the_text + '")');				
        break;

      case "assertTitle":
				// console.log("[assertTitle]" + request.title);
				request_title = escape_string(request.title);
				appendTo(ruby_editor, 'expect(driver.title).to eq("' + request_title + '")');				
				appendTo(python_editor, 'assertEqual("' + request_title + '", driver.title)'); 
				appendTo(javascript_editor, 'driver.getTitle().then(function(the_page_title) { \n  assert.equal("' +  request_title +'", the_page_title); \n});'); 
				appendTo(java_editor, 'assertEqual("' + request_title + '", driver.title)'); 
				appendTo(csharp_editor, 'Assert.AreEqual("' + request_title + '", driver.Title);'); 
				appendTo(watir_editor, 'expect(browser.title).to eq("' + request_title + '")');				
			  break;
				
      case "sendKeys":
				// console.log("[popup][sendKeys]" + request.text);
        appendTo(ruby_editor, 'driver.' +  determineLocator(elem, "ruby") + '.send_keys("' + request.text  + '")');
        appendTo(python_editor, 'driver.' +  determineLocator(elem, "python") + '.send_keys("' + request.text  + '")');
        appendTo(javascript_editor, 'driver.' +  determineLocator(elem, "javascript") + '.sendKeys("' + request.text  + '");');
        appendTo(java_editor, 'driver.' +  determineLocator(elem, "java") + '.sendKeys("' + request.text  + '");');
        appendTo(csharp_editor, 'driver.' +  determineLocator(elem, "csharp") + '.SendKeys("' + request.text  + '");');	
        appendTo(watir_editor, 'browser.element' +  determineLocator(elem, "watir") + '.set("' + request.text  + '")');
        break;
				
  	  case "enterText":
				// console.log("[popup][enterText]" );
        elem["value"] = escape_string(request.elem_value);				

        appendTo(ruby_editor, 'driver.' +  determineLocator(elem, "ruby") + '.send_keys("' + elem["value"]  + '")');
        appendTo(python_editor, 'driver.' +  determineLocator(elem, "python") + '.send_keys("' + elem["value"]  + '")');
        appendTo(javascript_editor, 'driver.' +  determineLocator(elem, "javascript") + '.sendKeys("' + elem["value"]  + '");');
        appendTo(java_editor, 'driver.' +  determineLocator(elem, "java") + '.sendKeys("' + elem["value"]  + '");');
        appendTo(csharp_editor, 'driver.' +  determineLocator(elem, "csharp") + '.SendKeys("' + elem["value"]  + '");');	
        appendTo(watir_editor, 'browser.text_field' +  determineLocator(elem, "watir") + '.set("' + elem["value"]  + '")');
				
        break;  	 
                

      case "enterPassword":
        // console.log("[popup][enterPassword]" );
        elem["value"] = escape_string(request.elem_value);

        appendTo(ruby_editor, 'driver.' +  determineLocator(elem, "ruby") + '.send_keys("' + elem["value"]  + '")');
        appendTo(python_editor, 'driver.' +  determineLocator(elem, "python") + '.send_keys("' + elem["value"]  + '")');
        appendTo(javascript_editor, 'driver.' +  determineLocator(elem, "javascript") + '.sendKeys("' + elem["value"]  + '");');
        appendTo(java_editor, 'driver.' +  determineLocator(elem, "java") + '.sendKeys("' + elem["value"]  + '");');
        appendTo(csharp_editor, 'driver.' +  determineLocator(elem, "csharp") + '.SendKeys("' + elem["value"]  + '");');	
        appendTo(watir_editor, 'browser.text_field' +  determineLocator(elem, "watir") + '.set("' + elem["value"]  + '")');
        break;
				
      case "enterTextArea":
        // console.log("[popup][enterTextArea]" );
        elem["value"] = escape_string(request.elem_value); 
        appendTo(ruby_editor, 'driver.' +  determineLocator(elem, "ruby") + '.send_keys("' + elem["value"]  + '")');
        appendTo(python_editor, 'driver.' +  determineLocator(elem, "python") + '.send_keys("' + elem["value"]  + '")');
        appendTo(javascript_editor, 'driver.' +  determineLocator(elem, "javascript") + '.sendKeys("' + elem["value"]  + '");');
        appendTo(java_editor, 'driver.' +  determineLocator(elem, "java") + '.sendKeys("' + elem["value"]  + '");');
        appendTo(csharp_editor, 'driver.' +  determineLocator(elem, "csharp") + '.SendKeys("' + elem["value"]  + '");');	  
        appendTo(watir_editor, 'browser.area' +  determineLocator(elem, "watir") + '.set("' + elem["value"]  + '")');
        break;
      
      case "uploadFile":
        // console.log("[popup][uploadFile]" );
        elem["value"] = escape_string(request.elem_value); 
        appendTo(ruby_editor, 'driver.' +  determineLocator(elem, "ruby") + '.send_keys("' + elem["value"]  + '")');
        appendTo(python_editor, 'driver.' +  determineLocator(elem, "python") + '.send_keys("' + elem["value"]  + '")');
        appendTo(javascript_editor, 'driver.' +  determineLocator(elem, "javascript") + '.sendKeys("' + elem["value"]  + '");');
        appendTo(java_editor, 'driver.' +  determineLocator(elem, "java") + '.sendKeys("' + elem["value"]  + '");');
        appendTo(csharp_editor, 'driver.' +  determineLocator(elem, "csharp") + '.SendKeys("' + elem["value"]  + '");');	  
        appendTo(watir_editor, 'browser.file_field' +  determineLocator(elem, "watir") + '.set("' + elem["value"]  + '")');
        break;
                            
      case "check":
        // console.log("[check]" + elem);
        appendTo(ruby_editor, 'driver.' +  determineLocator(elem, "ruby") + '.click');           
        appendTo(python_editor, 'driver.' +  determineLocator(elem, "python") + '.click()');    
        appendTo(javascript_editor, 'driver.' +  determineLocator(elem, "javascript") + '.click();');
        appendTo(java_editor, 'driver.' +  determineLocator(elem, "java") + '.click();');
        appendTo(csharp_editor, 'driver.' +  determineLocator(elem, "csharp") + '.Click();');        
        appendTo(watir_editor, 'browser.checkbox' +  determineLocator(elem, "watir") + '.set');                  				
        break;
  		  
      case "uncheck":
        // console.log("[uncheck]" + elem);
        appendTo(ruby_editor, 'driver.' +  determineLocator(elem, "ruby") + '.click');                  
        appendTo(python_editor, 'driver.' +  determineLocator(elem, "python") + '.click()');    
        appendTo(javascript_editor, 'driver.' +  determineLocator(elem, "javascript") + '.click();');
        appendTo(java_editor, 'driver.' +  determineLocator(elem, "java") + '.click();');
        appendTo(csharp_editor, 'driver.' +  determineLocator(elem, "csharp") + '.Click();');                      
        appendTo(watir_editor, 'browser.checkbox' +  determineLocator(elem, "watir") + '.clear');                  				
        break;
				
      case "setRadio":
        // console.log("[setRadio]" + elem);
        elem["value"] = request.elem_value;				
        if (elem["id"]) {
          appendTo(ruby_editor, 'driver.' +  determineLocator(elem, "ruby") + '.click');                  
	        appendTo(python_editor, 'driver.' +  determineLocator(elem, "python") + '.click()');                  
          appendTo(javascript_editor, 'driver.' +  determineLocator(elem, "javascript") + '.click();');
          appendTo(java_editor, 'driver.' +  determineLocator(elem, "java") + '.click();');
          appendTo(csharp_editor, 'driver.' +  determineLocator(elem, "csharp") + '.Click();');          
	        appendTo(watir_editor, 'browser.radio' +  determineLocator(elem, "watir") + '.set');                  
        } else {
          radio_xpath = '//input[@type=\'radio\' and @name=\'' +  elem["name"] +  '\' and @value=\'' + elem["value"] + '\']'
          appendTo(ruby_editor, 'driver.find_element(:xpath, "' + radio_xpath + '").click');
          appendTo(python_editor, 'driver.find_element_by_xpath("' + radio_xpath + '").click()');
          appendTo(javascript_editor, 'driver.findElement(By.xpath("' + radio_xpath +  '"))' + '.click();');
          appendTo(java_editor, 'driver.findElement(By.xpath("' + radio_xpath +  '"))' + '.click();');
          appendTo(csharp_editor, 'driver.FindElement(By.Xpath("' + radio_xpath +  '"))' + '.Click();');          
          appendTo(watir_editor, 'browser.radio(:name => "' + elem["name"] + '", :value => "' + elem["value"] + '").set');					
        }
        break;
                
      case "clickButton":
        appendTo(ruby_editor, 'driver.' +  determineLocator(elem, "ruby") + '.click');
        appendTo(python_editor, 'driver.' +  determineLocator(elem, "python") + '.click()');
        appendTo(javascript_editor, 'driver.' +  determineLocator(elem, "javascript") + '.click();');
        appendTo(java_editor, 'driver.' +  determineLocator(elem, "java") + '.click();');
        appendTo(csharp_editor, 'driver.' +  determineLocator(elem, "csharp") + '.Click();');        
        appendTo(watir_editor, 'browser.button' +  determineLocator(elem, "watir") + '.click');                          
        break;

      case "clickImageButton":
        appendTo(ruby_editor, 'driver.' +  determineLocator(elem, "ruby") + '.click');
        appendTo(python_editor, 'driver.' +  determineLocator(elem, "python") + '.click()');
        appendTo(javascript_editor, 'driver.' +  determineLocator(elem, "javascript") + '.click();');
        appendTo(java_editor, 'driver.' +  determineLocator(elem, "java") + '.click();');
        appendTo(csharp_editor, 'driver.' +  determineLocator(elem, "csharp") + '.Click();');
        appendTo(watir_editor, 'browser.input' +  determineLocator(elem, "watir") + '.click');                          
        break;
        
      case "clickImage":
        appendTo(ruby_editor, 'driver.' +  determineLocator(elem, "ruby") + '.click');
        appendTo(python_editor, 'driver.' +  determineLocator(elem, "python") + '.click()');
        appendTo(javascript_editor, 'driver.' +  determineLocator(elem, "javascript") + '.click();');
        appendTo(java_editor, 'driver.' +  determineLocator(elem, "java") + '.click();');
        appendTo(csharp_editor, 'driver.' +  determineLocator(elem, "csharp") + '.Click();');        
        appendTo(watir_editor, 'browser.image' +  determineLocator(elem, "watir") + '.click');                          
        break;
				
      case "clickLink":
        elem["linkText"] = escape_string(request.elem_link_text);				
				
        if (elem["linkText"]) {					

					// 5 rounds of remove \r\n from text if contains unncessary newline characters
					a = $.trim(elem["linkText"]);					
					for (i = 0; i < 6; i++) {
						a = a.replace(/^\s*(\\r\\n|\\n|\\r)/m, " ");
					  a = a.replace(/(\\r\\n|\\n|\\r)\s*$/m, " ");
						a = $.trim(a);
					}
					var trimedLinkText = a;

					if (elem["linkText"] != trimedLinkText) {
						// contains trailling spaces, typcial \n, 
	          appendTo(ruby_editor, 'driver.find_element(:partial_link_text, ' + '"' + trimedLinkText + '"' + ').click');                  
	          appendTo(python_editor, 'driver.find_element_by_partial_link_text("' + trimedLinkText + '").click()');                  
	          appendTo(javascript_editor, 'driver.findElement(By.partialLinkText("' + trimedLinkText + '")).click();');         
	          appendTo(java_editor, 'driver.findElement(By.partialLinkText("' + trimedLinkText + '")).click();');         
	          appendTo(csharp_editor, 'driver.FindElement(By.PartialLinkText("' + trimedLinkText + '")).Click();');         
	          appendTo(watir_editor, 'browser.link(:text => ' + '"' + elem["linkText"] + '"' + ').click');                  
				
					} else {

	          appendTo(ruby_editor, 'driver.find_element(:link_text, ' + '"' + elem["linkText"] + '"' + ').click');                  
	          appendTo(python_editor, 'driver.find_element_by_link_text("' + elem["linkText"] + '").click()');                  
	          appendTo(javascript_editor, 'driver.findElement(By.linkText("' + elem["linkText"] + '")).click();');         
	          appendTo(java_editor, 'driver.findElement(By.linkText("' + elem["linkText"] + '")).click();');         
	          appendTo(csharp_editor, 'driver.FindElement(By.LinkText("' + elem["linkText"] + '")).Click();');         
	          appendTo(watir_editor, 'browser.link(:text => ' + '"' + elem["linkText"] + '"' + ').click');                  

					}
					
        } else {					
          appendTo(ruby_editor, 'driver.' +  determineLocator(elem, "ruby") + '.click');
          appendTo(python_editor, 'driver.' +  determineLocator(elem, "python") + '.click()');
          appendTo(javascript_editor, 'driver.' +  determineLocator(elem, "javascript") + '.click();');
          appendTo(java_editor, 'driver.' +  determineLocator(elem, "java") + '.click();');
          appendTo(csharp_editor, 'driver.' +  determineLocator(elem, "csharp") + '.Click();');
          appendTo(watir_editor, 'browser.link' +  determineLocator(elem, "watir") + '.click');
				                  
        }						

				break;

			case "selectOption":
	      elem["value"] = escape_string(request.elem_value);
				elem["label"] = escape_string(request.elem_label);				
				if (elem["label"]) { 
			        appendTo(ruby_editor, 'Selenium::WebDriver::Support::Select.new(driver.' +  determineLocator(elem, "ruby") + ').select_by(:text, ' + '"' +  elem["label"]  + '")'); 
			        appendTo(python_editor, 'Select(driver.' +  determineLocator(elem, "python") + ').select_by_visible_text("' +  elem["label"]  + '")'); 
			        appendTo(javascript_editor, 'new Select(driver.' +  determineLocator(elem, "javascript") + ').selectByVisibleText("' +  elem["label"]  + '");'); 
			        appendTo(java_editor, 'new Select(driver.' +  determineLocator(elem, "java") + ').selectByVisibleText("' +  elem["label"]  + '");'); 
			        appendTo(csharp_editor, 'new SelectElement(driver.' +  determineLocator(elem, "csharp") + ').SelectByText("' +  elem["label"]  + '");'); 
			        appendTo(watir_editor, 'browser.select_list' +  determineLocator(elem, "watir") + '.select("' +  elem["label"]  + '")');										
				} else {
			        appendTo(ruby_editor, 'Selenium::WebDriver::Support::Select.new(driver.' +  determineLocator(elem, "ruby") + ').select_by(:value, ' + '"' +  elem["value"]  + '")'); 
			        appendTo(python_editor, 'Select(driver.' +  determineLocator(elem, "python") + ').select_by_visible_text("' +  elem["value"]  + '")'); 
			        appendTo(javascript_editor, 'new Select(driver.' +  determineLocator(elem, "javascript") + ').selectByValue("' +  elem["value"]  + '");'); 
			        appendTo(java_editor, 'new Select(driver.' +  determineLocator(elem, "java") + ').selectByValue("' +  elem["value"]  + '");'); 
			        appendTo(csharp_editor, 'new SelectElement(driver.' +  determineLocator(elem, "csharp") + ').SelectByValue("' +  elem["value"]  + '");'); 
			        appendTo(watir_editor, 'browser.select_list' +  determineLocator(elem, "watir") + '.select("' +  elem["value"]  + '")');						
				}				
				break;
        
      case "clickSpan":
        appendTo(ruby_editor, 'driver.' +  determineLocator(elem, "ruby") + '.click');
        appendTo(python_editor, 'driver.' +  determineLocator(elem, "python") + '.click()');
        appendTo(javascript_editor, 'driver.' +  determineLocator(elem, "javascript") + '.click();');
        appendTo(java_editor, 'driver.' +  determineLocator(elem, "java") + '.click();');
        appendTo(csharp_editor, 'driver.' +  determineLocator(elem, "csharp") + '.Click();');
        appendTo(watir_editor, 'browser.span' +  determineLocator(elem, "watir") + '.click');                          
        break;        

      case "clickIcon":
        appendTo(ruby_editor, 'driver.' +  determineLocator(elem, "ruby") + '.click');
        appendTo(python_editor, 'driver.' +  determineLocator(elem, "python") + '.click()');
        appendTo(javascript_editor, 'driver.' +  determineLocator(elem, "javascript") + '.click();');
        appendTo(java_editor, 'driver.' +  determineLocator(elem, "java") + '.click();');
        appendTo(csharp_editor, 'driver.' +  determineLocator(elem, "csharp") + '.Click();');
        appendTo(watir_editor, 'browser.i' +  determineLocator(elem, "watir") + '.click');                          
        break;        
      }      
      
		
      return true;     
	  }
	);
	
});